vsutillib.network package
=========================

The ``UrlRequest`` class
------------------------

.. autoclass:: vsutillib.network.UrlRequest
    :members:

The ``isConnected`` function
----------------------------

.. autofunction:: vsutillib.network.isConnected

The ``urlSearchJson`` function
------------------------------

.. autofunction:: vsutillib.network.urlSearchJson
